@@ -7,7 +7,10 @@
 use super::{AddressBook, ArchivedAddressBook, ArchivedContactCard, ContactCard};
 use crate::DestroyArchive;
 use common::{Server, auth::AccessToken, storage::index::ObjectIndexBuilder};
-use store::write::{Archive, BatchBuilder, now};
+use store::{
+    ValueKey,
+    write::{AlignedBytes, Archive, BatchBuilder, now},
+};
 use trc::AddContext;
 use types::collection::{Collection, VanishedCollection};
 
@@ -29,7 +32,7 @@ impl ContactCard {
         batch
             .with_account_id(account_id)
             .with_collection(Collection::ContactCard)
-            .update_document(document_id)
+            .with_document(document_id)
             .custom(
                 ObjectIndexBuilder::new()
                     .with_current(card)
@@ -56,7 +59,7 @@ impl ContactCard {
         batch
             .with_account_id(account_id)
             .with_collection(Collection::ContactCard)
-            .create_document(document_id)
+            .with_document(document_id)
             .custom(
                 ObjectIndexBuilder::<(), _>::new()
                     .with_changes(card)
@@ -84,7 +87,7 @@ impl AddressBook {
         batch
             .with_account_id(account_id)
             .with_collection(Collection::AddressBook)
-            .create_document(document_id)
+            .with_document(document_id)
             .custom(
                 ObjectIndexBuilder::<(), _>::new()
                     .with_changes(book)
@@ -109,7 +112,7 @@ impl AddressBook {
         batch
             .with_account_id(account_id)
             .with_collection(Collection::AddressBook)
-            .update_document(document_id)
+            .with_document(document_id)
             .custom(
                 ObjectIndexBuilder::new()
                     .with_current(book)
@@ -136,7 +139,12 @@ impl DestroyArchive<Archive<&ArchivedAddressBook>> {
         let addressbook_id = document_id;
         for document_id in children_ids {
             if let Some(card_) = server
-                .get_archive(account_id, Collection::ContactCard, document_id)
+                .store()
+                .get_value::<Archive<AlignedBytes>>(ValueKey::archive(
+                    account_id,
+                    Collection::ContactCard,
+                    document_id,
+                ))
                 .await?
             {
                 DestroyArchive(
@@ -171,7 +179,7 @@ impl DestroyArchive<Archive<&ArchivedAddressBook>> {
         batch
             .with_account_id(account_id)
             .with_collection(Collection::AddressBook)
-            .delete_document(document_id)
+            .with_document(document_id)
             .custom(
                 ObjectIndexBuilder::<_, ()>::new()
                     .with_access_token(access_token)
@@ -217,7 +225,7 @@ impl DestroyArchive<Archive<&ArchivedContactCard>> {
                     .caused_by(trc::location!())?;
                 new_card.names.swap_remove(delete_idx);
                 batch
-                    .update_document(document_id)
+                    .with_document(document_id)
                     .custom(
                         ObjectIndexBuilder::new()
                             .with_access_token(access_token)
@@ -228,7 +236,7 @@ impl DestroyArchive<Archive<&ArchivedContactCard>> {
             } else {
                 // Delete card
                 batch
-                    .delete_document(document_id)
+                    .with_document(document_id)
                     .custom(
                         ObjectIndexBuilder::<_, ()>::new()
                             .with_access_token(access_token)
@@ -257,7 +265,7 @@ impl DestroyArchive<Archive<&ArchivedContactCard>> {
         batch
             .with_account_id(account_id)
             .with_collection(Collection::ContactCard)
-            .delete_document(document_id)
+            .with_document(document_id)
             .custom(
                 ObjectIndexBuilder::<_, ()>::new()
                     .with_access_token(access_token)
