@@ -29,7 +29,7 @@ use rand::{Rng, distr::Alphanumeric};
 use store::{
     SerializeInfallible, ValueKey,
     ahash::AHashSet,
-    write::{BatchBuilder, ValueClass},
+    write::{AlignedBytes, Archive, BatchBuilder, ValueClass},
 };
 use trc::AddContext;
 use types::{
@@ -136,7 +136,12 @@ impl CalendarSet for Server {
             // Obtain calendar
             let document_id = id.document_id();
             let calendar_ = if let Some(calendar_) = self
-                .get_archive(account_id, Collection::Calendar, document_id)
+                .store()
+                .get_value::<Archive<AlignedBytes>>(ValueKey::archive(
+                    account_id,
+                    Collection::Calendar,
+                    document_id,
+                ))
                 .await?
             {
                 calendar_
@@ -214,7 +219,12 @@ impl CalendarSet for Server {
                 };
 
                 let Some(calendar_) = self
-                    .get_archive(account_id, Collection::Calendar, document_id)
+                    .store()
+                    .get_value::<Archive<AlignedBytes>>(ValueKey::archive(
+                        account_id,
+                        Collection::Calendar,
+                        document_id,
+                    ))
                     .await
                     .caused_by(trc::location!())?
                 else {
@@ -269,7 +279,12 @@ impl CalendarSet for Server {
             if !destroy_children.is_empty() {
                 for document_id in destroy_children {
                     if let Some(event_) = self
-                        .get_archive(account_id, Collection::CalendarEvent, document_id)
+                        .store()
+                        .get_value::<Archive<AlignedBytes>>(ValueKey::archive(
+                            account_id,
+                            Collection::CalendarEvent,
+                            document_id,
+                        ))
                         .await?
                     {
                         let event = event_
@@ -323,7 +338,7 @@ impl CalendarSet for Server {
                 batch
                     .with_account_id(account_id)
                     .with_collection(Collection::Principal)
-                    .update_document(0)
+                    .with_document(0)
                     .set(
                         PrincipalField::DefaultCalendarId,
                         default_calendar_id.serialize(),
@@ -333,7 +348,7 @@ impl CalendarSet for Server {
             batch
                 .with_account_id(account_id)
                 .with_collection(Collection::Principal)
-                .update_document(0)
+                .with_document(0)
                 .clear(PrincipalField::DefaultCalendarId);
         }
 
@@ -345,6 +360,7 @@ impl CalendarSet for Server {
                 .caused_by(trc::location!())?
                 .last_change_id(account_id)
         {
+            self.notify_task_queue();
             response.new_state = State::Exact(change_id).into();
         }
 
