@@ -19,9 +19,9 @@ use jmap_tools::{Key, Map, Value};
 use rand::distr::Alphanumeric;
 use std::future::Future;
 use store::{
-    Serialize,
+    Serialize, ValueKey,
     rand::{Rng, rng},
-    write::{Archiver, BatchBuilder, now},
+    write::{AlignedBytes, Archive, Archiver, BatchBuilder, now},
 };
 use trc::{AddContext, ServerEvent};
 use types::{collection::Collection, field::PrincipalField};
@@ -47,12 +47,13 @@ impl PushSubscriptionSet for Server {
         // Load existing push subscriptions
         let account_id = access_token.primary_id();
         let subscriptions_archive = self
-            .get_archive_by_property(
+            .store()
+            .get_value::<Archive<AlignedBytes>>(ValueKey::property(
                 account_id,
                 Collection::Principal,
                 0,
-                PrincipalField::PushSubscriptions.into(),
-            )
+                PrincipalField::PushSubscriptions,
+            ))
             .await?;
         let mut subscriptions = if let Some(subscriptions) = &subscriptions_archive {
             subscriptions
@@ -206,19 +207,21 @@ impl PushSubscriptionSet for Server {
             if subscriptions_archive.is_none() {
                 batch
                     .with_account_id(u32::MAX)
-                    .with_collection(Collection::PushSubscription)
-                    .create_document(account_id);
+                    .with_collection(Collection::Principal)
+                    .with_document(account_id)
+                    .tag(PrincipalField::PushSubscriptions);
             } else if subscriptions.subscriptions.is_empty() {
                 batch
                     .with_account_id(u32::MAX)
-                    .with_collection(Collection::PushSubscription)
-                    .delete_document(account_id);
+                    .with_collection(Collection::Principal)
+                    .with_document(account_id)
+                    .untag(PrincipalField::PushSubscriptions);
             }
 
             batch
                 .with_account_id(account_id)
                 .with_collection(Collection::Principal)
-                .update_document(0);
+                .with_document(0);
 
             if let Some(subscriptions_archive) = subscriptions_archive {
                 batch.assert_value(PrincipalField::PushSubscriptions, subscriptions_archive);
