@@ -1,13 +1,12 @@
 /*
- * SPDX-FileCopyrightText: 2020 Stalwart Labs Ltd <hello@stalw.art>
+ * SPDX-FileCopyrightText: 2020 Stalwart Labs LLC <hello@stalw.art>
  *
  * SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-SEL
  */
 
+use foundationdb::{Database, FdbError, api::NetworkAutoStop};
 use std::time::{Duration, Instant};
 
-use foundationdb::{Database, FdbError, Transaction, api::NetworkAutoStop};
-
 pub mod blob;
 pub mod main;
 pub mod read;
@@ -15,7 +14,6 @@ pub mod write;
 
 const MAX_VALUE_SIZE: usize = 100000;
 pub const TRANSACTION_EXPIRY: Duration = Duration::from_secs(1);
-pub const TRANSACTION_TIMEOUT: Duration = Duration::from_secs(4);
 
 #[allow(dead_code)]
 pub struct FdbStore {
@@ -24,11 +22,6 @@ pub struct FdbStore {
     version: parking_lot::Mutex<ReadVersion>,
 }
 
-pub(crate) struct TimedTransaction {
-    trx: Transaction,
-    expires: Instant,
-}
-
 pub(crate) struct ReadVersion {
     version: i64,
     expires: Instant,
@@ -56,25 +49,6 @@ impl Default for ReadVersion {
     }
 }
 
-impl AsRef<Transaction> for TimedTransaction {
-    fn as_ref(&self) -> &Transaction {
-        &self.trx
-    }
-}
-
-impl TimedTransaction {
-    pub fn new(trx: Transaction) -> Self {
-        Self {
-            trx,
-            expires: Instant::now() + TRANSACTION_TIMEOUT,
-        }
-    }
-
-    pub fn is_expired(&self) -> bool {
-        self.expires < Instant::now()
-    }
-}
-
 #[inline(always)]
 fn into_error(error: FdbError) -> trc::Error {
     trc::StoreEvent::FoundationdbError
