@@ -58,25 +58,39 @@ impl PostgresStore {
 
                 if let Some(value) = fields.get(field) {
                     let value_ref = format!("${}", values.len() + 1);
+                    let (text_len, language) = if let SearchValue::Text { value, language } = value
+                    {
+                        (
+                            value.len(),
+                            if self.languages.contains(language) {
+                                pg_lang(language).unwrap_or("simple")
+                            } else {
+                                "simple"
+                            },
+                        )
+                    } else {
+                        (0, "simple")
+                    };
 
                     if field.is_text() {
-                        let language = match &value {
-                            SearchValue::Text { language, .. }
-                                if self.languages.contains(language) =>
-                            {
-                                pg_lang(language).unwrap_or("simple")
-                            }
-                            _ => "simple",
-                        };
-
                         let _ = write!(&mut query, "to_tsvector('{language}',{value_ref})");
+                    } else if text_len > 512 {
+                        query.push_str("left(");
+                        query.push_str(&value_ref);
+                        query.push_str(",512)");
                     } else {
                         query.push_str(&value_ref);
                     }
 
                     if field.sort_column().is_some() {
-                        query.push(',');
-                        query.push_str(&value_ref);
+                        if text_len > 255 {
+                            query.push_str(",left(");
+                            query.push_str(&value_ref);
+                            query.push_str(",255)");
+                        } else {
+                            query.push(',');
+                            query.push_str(&value_ref);
+                        }
                     }
 
                     values.push(value as &(dyn ToSql + Sync));
@@ -301,7 +315,15 @@ impl ToSql for SearchValue {
         Self: Sized,
     {
         match self {
-            SearchValue::Text { value, .. } => value.to_sql(ty, out),
+            SearchValue::Text { value, .. } => {
+                // Truncate large text fields to avoid Postgres errors (see https://www.postgresql.org/docs/current/textsearch-limitations.html)
+
+                if value.len() > 650_000 {
+                    (&value[..value.floor_char_boundary(650_000)]).to_sql(ty, out)
+                } else {
+                    value.to_sql(ty, out)
+                }
+            }
             SearchValue::Int(v) => match *ty {
                 Type::INT4 => (*v as i32).to_sql(ty, out),
                 _ => v.to_sql(ty, out),
@@ -330,7 +352,15 @@ impl ToSql for SearchValue {
         out: &mut bytes::BytesMut,
     ) -> Result<tokio_postgres::types::IsNull, Box<dyn std::error::Error + Sync + Send>> {
         match self {
-            SearchValue::Text { value, .. } => value.to_sql_checked(ty, out),
+            SearchValue::Text { value, .. } => {
+                // Truncate large text fields to avoid Postgres errors (see https://www.postgresql.org/docs/current/textsearch-limitations.html)
+
+                if value.len() > 650_000 {
+                    (&value[..value.floor_char_boundary(650_000)]).to_sql_checked(ty, out)
+                } else {
+                    value.to_sql_checked(ty, out)
+                }
+            }
             SearchValue::Int(v) => match *ty {
                 Type::INT4 => (*v as i32).to_sql_checked(ty, out),
                 _ => v.to_sql_checked(ty, out),
