@@ -11,23 +11,26 @@ use nlp::tokenizers::word::WordTokenizer;
 use rkyv::util::AlignedVec;
 use std::{
     collections::HashSet,
+    hash::Hash,
     time::{Duration, SystemTime},
 };
 use types::{
     blob_hash::BlobHash,
     collection::{Collection, SyncCollection, VanishedCollection},
     field::{
-        CalendarField, ContactField, EmailField, EmailSubmissionField, Field, MailboxField,
-        PrincipalField, SieveField,
+        CalendarEventField, CalendarNotificationField, ContactField, EmailField,
+        EmailSubmissionField, Field, MailboxField, PrincipalField, SieveField,
     },
 };
-use utils::map::{bitmap::Bitmap, vec_map::VecMap};
+use utils::{
+    cheeky_hash::CheekyHash,
+    map::{bitmap::Bitmap, vec_map::VecMap},
+};
 
 pub mod assert;
 pub mod batch;
 pub mod bitpack;
 pub mod blob;
-pub mod hash;
 pub mod key;
 pub mod log;
 pub mod serialize;
@@ -71,6 +74,7 @@ where
 #[derive(Debug, Default)]
 pub struct AssignedIds {
     pub ids: Vec<AssignedId>,
+    current_change_id: Option<u64>,
 }
 
 #[derive(Debug)]
@@ -146,10 +150,6 @@ pub enum Operation {
         key: Vec<u8>,
         set: bool,
     },
-    Bitmap {
-        class: BitmapClass,
-        set: bool,
-    },
     Log {
         collection: LogCollection,
         set: Vec<u8>,
@@ -162,31 +162,12 @@ pub enum LogCollection {
     Vanished(VanishedCollection),
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash)]
-pub enum BitmapClass {
-    DocumentIds,
-    Tag { field: u8, value: TagValue },
-    Text { field: u8, token: BitmapHash },
-}
-
-#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
-pub struct BitmapHash {
-    pub hash: [u8; 8],
-    pub len: u8,
-}
-
-#[derive(Debug, Clone, PartialEq, Eq, Hash)]
-pub enum TagValue {
-    Id(u32),
-    Text(Vec<u8>),
-}
-
 #[derive(Debug, PartialEq, Clone, Eq, Hash)]
 pub enum ValueClass {
     Property(u8),
+    IndexProperty(IndexPropertyClass),
     Acl(u32),
     InMemory(InMemoryClass),
-    FtsIndex(BitmapHash),
     TaskQueue(TaskQueueClass),
     Directory(DirectoryClass),
     Blob(BlobOp),
@@ -194,6 +175,7 @@ pub enum ValueClass {
     Queue(QueueClass),
     Report(ReportClass),
     Telemetry(TelemetryClass),
+    SearchIndex(SearchIndexClass),
     Any(AnyClass),
     ShareNotification {
         notification_id: u64,
@@ -203,27 +185,74 @@ pub enum ValueClass {
     ChangeId,
 }
 
+#[derive(Debug, PartialEq, Clone, Eq, Hash)]
+pub enum IndexPropertyClass {
+    Hash { property: u8, hash: CheekyHash },
+    Integer { property: u8, value: u64 },
+}
+
+#[derive(Debug, PartialEq, Clone, Eq, Hash)]
+pub struct SearchIndexClass {
+    pub index: SearchIndex,
+    pub id: SearchIndexId,
+    pub typ: SearchIndexType,
+}
+
+#[derive(Debug, PartialEq, Clone, Eq, Hash)]
+pub enum SearchIndexType {
+    Term { field: u8, hash: CheekyHash },
+    Index { field: SearchIndexField },
+    Document,
+}
+
+pub(crate) const SEARCH_INDEX_MAX_FIELD_LEN: usize = 128;
+
+#[derive(Debug, PartialEq, Eq, Clone, Hash, rkyv::Serialize, rkyv::Deserialize, rkyv::Archive)]
+pub struct SearchIndexField {
+    pub(crate) field_id: u8,
+    pub(crate) data: Vec<u8>,
+}
+
+#[derive(Debug, PartialEq, Clone, Copy, Eq, Hash)]
+pub enum SearchIndexId {
+    Account { account_id: u32, document_id: u32 },
+    Global { id: u64 },
+}
+
 #[derive(Debug, PartialEq, Clone, Eq, Hash)]
 pub enum TaskQueueClass {
-    IndexEmail {
-        due: u64,
-        hash: BlobHash,
-    },
-    BayesTrain {
-        due: u64,
-        hash: BlobHash,
-        learn_spam: bool,
+    UpdateIndex {
+        due: TaskEpoch,
+        index: SearchIndex,
+        is_insert: bool,
     },
     SendAlarm {
-        due: u64,
+        due: TaskEpoch,
         event_id: u16,
         alarm_id: u16,
         is_email_alert: bool,
     },
     SendImip {
-        due: u64,
+        due: TaskEpoch,
         is_payload: bool,
     },
+    MergeThreads {
+        due: TaskEpoch,
+    },
+}
+
+#[derive(Debug, PartialEq, Clone, Copy, Eq, Hash)]
+#[repr(transparent)]
+pub struct TaskEpoch(pub(crate) u64);
+
+#[derive(Debug, PartialEq, Clone, Copy, Eq, Hash)]
+pub enum SearchIndex {
+    Email,
+    Calendar,
+    Contacts,
+    File,
+    Tracing,
+    InMemory,
 }
 
 #[derive(Debug, PartialEq, Clone, Eq, Hash)]
@@ -278,10 +307,6 @@ pub enum TelemetryClass {
         metric_id: u64,
         node_id: u64,
     },
-    Index {
-        span_id: u64,
-        value: Vec<u8>,
-    },
 }
 
 #[derive(Debug, PartialEq, Clone, Eq, Hash)]
@@ -301,29 +326,63 @@ pub struct ReportEvent {
 
 #[derive(Debug, PartialEq, Eq, Hash, Default)]
 pub enum ValueOp {
-    Set {
-        value: Vec<u8>,
-        version_offset: Option<usize>,
-    },
+    Set(Vec<u8>),
+    SetFnc(SetOperation),
+    MergeFnc(MergeOperation),
     AtomicAdd(i64),
     AddAndGet(i64),
-    Merge(MergeFn),
     #[default]
     Clear,
 }
 
-#[allow(clippy::type_complexity)]
-pub struct MergeFn {
-    pub fnc: Box<dyn Fn(Option<&[u8]>) -> trc::Result<Vec<u8>> + Send + Sync>,
-    pub fnc_id: u64,
+pub enum MergeResult {
+    Update(Vec<u8>),
+    Skip,
+    Delete,
+}
+
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+pub enum Param {
+    I64(i64),
+    U64(u64),
+    String(String),
+    Bytes(Vec<u8>),
+    Bool(bool),
+}
+
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[repr(transparent)]
+pub struct Params(Vec<Param>);
+
+pub type SetFnc = fn(&Params, &AssignedIds) -> trc::Result<Vec<u8>>;
+pub type MergeFnc = fn(&Params, &AssignedIds, Option<&[u8]>) -> trc::Result<MergeResult>;
+
+#[derive(Debug, Clone)]
+pub struct MergeOperation {
+    pub(crate) fnc: MergeFnc,
+    pub(crate) params: Params,
+}
+
+#[derive(Debug, Clone)]
+pub struct SetOperation {
+    pub(crate) fnc: SetFnc,
+    pub(crate) params: Params,
 }
 
 #[derive(Debug, PartialEq, Clone, Eq, Hash)]
 pub enum BlobOp {
-    Reserve { hash: BlobHash, until: u64 },
     Commit { hash: BlobHash },
-    Link { hash: BlobHash },
-    LinkId { hash: BlobHash, id: u64 },
+    Link { hash: BlobHash, to: BlobLink },
+    Quota { hash: BlobHash, until: u64 },
+    Undelete { hash: BlobHash, until: u64 },
+    SpamSample { hash: BlobHash, until: u64 },
+}
+
+#[derive(Debug, PartialEq, Clone, Eq, Hash)]
+pub enum BlobLink {
+    Id { id: u64 },
+    Document,
+    Temporary { until: u64 },
 }
 
 #[derive(Debug, PartialEq, Clone, Eq, Hash)]
@@ -332,36 +391,6 @@ pub struct AnyKey<T: AsRef<[u8]>> {
     pub key: T,
 }
 
-impl From<u32> for TagValue {
-    fn from(value: u32) -> Self {
-        TagValue::Id(value)
-    }
-}
-
-impl From<Vec<u8>> for TagValue {
-    fn from(value: Vec<u8>) -> Self {
-        TagValue::Text(value)
-    }
-}
-
-impl From<String> for TagValue {
-    fn from(value: String) -> Self {
-        TagValue::Text(value.into_bytes())
-    }
-}
-
-impl From<u8> for TagValue {
-    fn from(value: u8) -> Self {
-        TagValue::Id(value as u32)
-    }
-}
-
-impl From<()> for TagValue {
-    fn from(_: ()) -> Self {
-        TagValue::Text(vec![])
-    }
-}
-
 pub trait TokenizeText {
     fn tokenize_into(&self, tokens: &mut HashSet<String>);
     fn to_tokens(&self) -> HashSet<String>;
@@ -398,24 +427,6 @@ impl AsRef<ValueClass> for ValueClass {
     }
 }
 
-impl AsRef<BitmapClass> for BitmapClass {
-    fn as_ref(&self) -> &BitmapClass {
-        self
-    }
-}
-
-impl BitmapClass {
-    pub fn tag_id(property: impl Into<u8>, id: u32) -> Self
-    where
-        TagValue: From<u32>,
-    {
-        BitmapClass::Tag {
-            field: property.into(),
-            value: id.into(),
-        }
-    }
-}
-
 impl AssignedIds {
     pub fn push_counter_id(&mut self, id: i64) {
         self.ids.push(AssignedId::Counter(id));
@@ -445,6 +456,20 @@ impl AssignedIds {
             })
     }
 
+    pub fn current_change_id(&self) -> trc::Result<u64> {
+        self.current_change_id.ok_or_else(|| {
+            trc::StoreEvent::UnexpectedError
+                .caused_by(trc::location!())
+                .ctx(trc::Key::Reason, "No current change id is set")
+        })
+    }
+
+    pub(crate) fn set_current_change_id(&mut self, account_id: u32) -> trc::Result<u64> {
+        let change_id = self.last_change_id(account_id)?;
+        self.current_change_id = Some(change_id);
+        Ok(change_id)
+    }
+
     pub fn last_counter_id(&self) -> trc::Result<i64> {
         self.ids
             .iter()
@@ -477,15 +502,6 @@ impl<T: AsRef<[u8]>> AsRef<[u8]> for Archive<T> {
     }
 }
 
-impl TagValue {
-    pub fn serialized_size(&self) -> usize {
-        match self {
-            TagValue::Id(_) => std::mem::size_of::<u32>(),
-            TagValue::Text(items) => items.len(),
-        }
-    }
-}
-
 impl ArchiveVersion {
     pub fn hash(&self) -> Option<u32> {
         match self {
@@ -512,36 +528,20 @@ impl From<LogCollection> for u8 {
     }
 }
 
-impl std::fmt::Debug for MergeFn {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("MergeFn")
-            .field("fnc_id", &self.fnc_id)
-            .finish()
-    }
-}
-
-impl PartialEq for MergeFn {
-    fn eq(&self, other: &Self) -> bool {
-        self.fnc_id == other.fnc_id
-    }
-}
-
-impl Eq for MergeFn {}
-
-impl std::hash::Hash for MergeFn {
-    fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
-        self.fnc_id.hash(state);
-    }
-}
-
 impl From<ContactField> for ValueClass {
     fn from(value: ContactField) -> Self {
         ValueClass::Property(value.into())
     }
 }
 
-impl From<CalendarField> for ValueClass {
-    fn from(value: CalendarField) -> Self {
+impl From<CalendarEventField> for ValueClass {
+    fn from(value: CalendarEventField) -> Self {
+        ValueClass::Property(value.into())
+    }
+}
+
+impl From<CalendarNotificationField> for ValueClass {
+    fn from(value: CalendarNotificationField) -> Self {
         ValueClass::Property(value.into())
     }
 }
@@ -581,3 +581,195 @@ impl From<Field> for ValueClass {
         ValueClass::Property(value.into())
     }
 }
+
+impl PartialEq for MergeOperation {
+    fn eq(&self, other: &Self) -> bool {
+        self.params == other.params
+    }
+}
+
+impl Eq for MergeOperation {}
+
+impl PartialEq for SetOperation {
+    fn eq(&self, other: &Self) -> bool {
+        self.params == other.params
+    }
+}
+
+impl Eq for SetOperation {}
+
+impl Hash for MergeOperation {
+    fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
+        self.params.hash(state);
+    }
+}
+
+impl Hash for SetOperation {
+    fn hash<H: std::hash::Hasher>(&self, state: &mut H) {
+        self.params.hash(state);
+    }
+}
+
+impl SetOperation {
+    pub fn params(&self) -> &Params {
+        &self.params
+    }
+}
+
+impl MergeOperation {
+    pub fn params(&self) -> &Params {
+        &self.params
+    }
+}
+
+impl Params {
+    pub fn with_capacity(capacity: usize) -> Self {
+        Self(Vec::with_capacity(capacity))
+    }
+
+    pub fn new() -> Self {
+        Self(Vec::new())
+    }
+
+    pub fn with_i64(mut self, value: i64) -> Self {
+        self.0.push(Param::I64(value));
+        self
+    }
+
+    pub fn with_u64(mut self, value: u64) -> Self {
+        self.0.push(Param::U64(value));
+        self
+    }
+
+    pub fn with_string(mut self, value: String) -> Self {
+        self.0.push(Param::String(value));
+        self
+    }
+
+    pub fn with_str(mut self, value: &str) -> Self {
+        self.0.push(Param::String(value.to_string()));
+        self
+    }
+
+    pub fn with_bytes(mut self, value: Vec<u8>) -> Self {
+        self.0.push(Param::Bytes(value));
+        self
+    }
+
+    pub fn with_bool(mut self, value: bool) -> Self {
+        self.0.push(Param::Bool(value));
+        self
+    }
+
+    pub fn i64(&self, idx: usize) -> i64 {
+        match &self.0[idx] {
+            Param::I64(v) => *v,
+            _ => panic!("Param at index {} is not an i64", idx),
+        }
+    }
+
+    pub fn u64(&self, idx: usize) -> u64 {
+        match &self.0[idx] {
+            Param::U64(v) => *v,
+            _ => panic!("Param at index {} is not a u64", idx),
+        }
+    }
+
+    pub fn string(&self, idx: usize) -> &str {
+        match &self.0[idx] {
+            Param::String(v) => v.as_str(),
+            _ => panic!("Param at index {} is not a String", idx),
+        }
+    }
+
+    pub fn bytes(&self, idx: usize) -> &[u8] {
+        match &self.0[idx] {
+            Param::Bytes(v) => v.as_slice(),
+            _ => panic!("Param at index {} is not Bytes", idx),
+        }
+    }
+
+    pub fn bool(&self, idx: usize) -> bool {
+        match &self.0[idx] {
+            Param::Bool(v) => *v,
+            _ => panic!("Param at index {} is not a bool", idx),
+        }
+    }
+
+    pub fn len(&self) -> usize {
+        self.0.len()
+    }
+
+    pub fn is_empty(&self) -> bool {
+        self.0.is_empty()
+    }
+
+    pub fn as_slice(&self) -> &[Param] {
+        &self.0
+    }
+}
+
+impl Default for Params {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
+impl AsRef<[Param]> for Params {
+    fn as_ref(&self) -> &[Param] {
+        &self.0
+    }
+}
+
+impl TaskEpoch {
+    /*
+      Structure of the 64-bit epoch:
+       4 bytes: seconds since custom epoch (1632280000)
+       2 bytes: attempt number
+       2 bytes: sequence id
+    */
+
+    const EPOCH_OFFSET: u64 = 1632280000;
+
+    pub fn now() -> Self {
+        Self::new(now())
+    }
+
+    pub fn new(timestamp: u64) -> Self {
+        Self(timestamp.saturating_sub(Self::EPOCH_OFFSET) << 32)
+    }
+
+    pub fn with_attempt(mut self, attempt: u16) -> Self {
+        self.0 |= (attempt as u64) << 16;
+        self
+    }
+
+    pub fn with_sequence_id(mut self, sequence_id: u16) -> Self {
+        self.0 |= sequence_id as u64;
+        self
+    }
+
+    pub fn with_random_sequence_id(self) -> Self {
+        self.with_sequence_id(rand::random())
+    }
+
+    pub fn due(&self) -> u64 {
+        (self.0 >> 32) + Self::EPOCH_OFFSET
+    }
+
+    pub fn attempt(&self) -> u16 {
+        (self.0 >> 16) as u16
+    }
+
+    pub fn sequence_id(&self) -> u16 {
+        self.0 as u16
+    }
+
+    pub fn inner(&self) -> u64 {
+        self.0
+    }
+
+    pub fn from_inner(inner: u64) -> Self {
+        Self(inner)
+    }
+}
